# **********************************************************************
# Copyright 2015 VMware, Inc.  All rights reserved. VMware Confidential.
# **********************************************************************
# $Id$
# $DateTime$
# $Change$
# $Author$
# **********************************************************************
import uuid


class LogicalSwitch(object):
    def __init__(self, **kwargs):
        prop_defaults = {
            "uuid_val": None,
            "dvs_name": None,
            "vni": None,
            "name": None,
            "mcast_ip": None,
            "mcast_proxy_enable": None,
            "arp_proxy_enable": None,
            "cp_conn_up": None,
            "controller_ip": None,
            "num_BTEs": None,
            "macTblLimit": None,
            "num_ARPs": None,
            "num_ports": None,
            "num_MTEPs": None,
            "replication_mode": None,
            "transport_binding": None,
            "vlan_id": None,
            "admin_state_up": None,
            "routing_domain_id": None,
            "mRouting_domain_id": None}
        for (prop, default) in list(prop_defaults.items()):
            setattr(self, prop, kwargs.get(prop, default))

    def json_repr(self):
        return self.__dict__


class MacTableEntry(object):
    def __init__(self, **kwargs):
        prop_defaults = {
            "inner_mac": None,
            "outer_mac": None,
            "outer_ip": None,
            "flags": None}
        for (prop, default) in list(prop_defaults.items()):
            setattr(self, prop, kwargs.get(prop, default))

    def json_repr(self):
        return self.__dict__


class VtepTableEntry(object):
    def __init__(self, **kwargs):
        prop_defaults = {
            "label": None,
            "ip_addr": None,
            "seg_id": None,
            "is_MTEP": None,
            "mac": None,
            "dev_name": None,
            "BFDCount": None,
            "expireSec": None,
            "upTimeSec": None}
        for (prop, default) in list(prop_defaults.items()):
            setattr(self, prop, kwargs.get(prop, default))

    def json_repr(self):
        return self.__dict__


class VtepGroupTableEntry(object):
    def __init__(self, **kwargs):
        prop_defaults = {
            "label": None,
            "type": None,
            "haType": None,
            "numMbr": None,
            "state": None,
            "activeMbr": None,
            "haSyncTime": None,
            "mbrVtep": None}
        for (prop, default) in list(prop_defaults.items()):
            setattr(self, prop, kwargs.get(prop, default))

    def json_repr(self):
        return self.__dict__


class MbrVtepTableEntry(object):
    def __init__(self, **kwargs):
        prop_defaults = {
            "label": None,
            "ip_addr": None,
            "mac": None,
            "encapType": None,
            "state": None}
        for (prop, default) in list(prop_defaults.items()):
            setattr(self, prop, kwargs.get(prop, default))

    def json_repr(self):
        return self.__dict__


class GlobalVtepTableEntry(object):
    def __init__(self, **kwargs):
        prop_defaults = {
            "label": None,
            "ip_addr": None,
            "seg_id": None,
            "mac": None,
            "encap_type": None,
            "vlan": None,
            "flags": None,
            "dev_name": None}
        for (prop, default) in list(prop_defaults.items()):
            setattr(self, prop, kwargs.get(prop, default))

    def json_repr(self):
        return self.__dict__


class ArpTableEntry(object):
    def __init__(self, **kwargs):
        prop_defaults = {
            "ip": None,
            "mac": None,
            "flags": None}
        for (prop, default) in list(prop_defaults.items()):
            setattr(self, prop, kwargs.get(prop, default))

    def json_repr(self):
        return self.__dict__


class NDTableEntry(object):
    def __init__(self, **kwargs):
        prop_defaults = {
            "ip": None,
            "mac": None,
            "flags": None}
        for (prop, default) in list(prop_defaults.items()):
            setattr(self, prop, kwargs.get(prop, default))

    def json_repr(self):
        return self.__dict__


class LogicalSwitchId(object):
    def __init__(self, ls_id):
        self.ls_uuid = None
        self.ls_vni = None
        self.ls_vlan = None
        try:
            uuid.UUID(ls_id)
            self.ls_uuid = ls_id
        except ValueError:
            is_vni = True
            lower_id = ls_id.lower()
            if lower_id.startswith("vlan:"):
                ls_id = lower_id[5:]
                is_vni = False
            ls_id = int(ls_id)
            if is_vni:
                self.ls_vni = ls_id
            else:
                self.ls_vlan = ls_id


class RoutingDomainUuid(object):
    def __init__(self, rd_id):
        self.rd_uuid = None
        try:
            uuid.UUID(rd_id)
            self.rd_uuid = rd_id
        except ValueError:
            self.rd_uuid = None
