# **********************************************************************
# Copyright 2017 VMware, Inc.  All rights reserved. VMware Confidential.
# **********************************************************************
# $Id$
# $DateTime$
# $Change$
# $Author$
# **********************************************************************
import nsx_logging
import json

from cli.commands.cli_command_provider import CliCommandProvider
from cli.commands.lcp_common.hyperbus.client import get_hyperbus_cli_output

lg = nsx_logging.getLogger("cli.commands.lcp_common.hyperbus.rpc_server")

def load_response_output(response):
    try:
        if response is None:
            return None
        output = json.loads(response)
    except (TypeError, ValueError) as err:
        lg.error("load response error: %s", err)
        return None
    return output

class GetVIFConnectionInfo(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_hyperbus_cli_output("vif/connections")
        output = load_response_output(response)
        if output is None:
            return "MSG_HOST_VIF_CONNECTION_FAILED"

        return "OK\n\n%s" % json.dumps(output)

class GetVIFConnectionInfoESX(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_hyperbus_cli_output("vif/connections")
        output = load_response_output(response)
        if output is None:
            return "MSG_HOST_VIF_CONNECTION_FAILED"

        return "OK\n\n%s" % json.dumps(output)

class GetConnectionInfoByVIFID(CliCommandProvider):
    def __call__(self, cmd_list):
        vifID = cmd_list[3]
        response = get_hyperbus_cli_output("vif/connection", [vifID])
        output = load_response_output(response)
        if output is None:
            return "MSG_HOST_VIF_CONNECTION_COMMON_FAILED"

        return "OK\n\n%s" % json.dumps(output)
