# Copyright (C) 2020 VMware, Inc. All rights reserved.
# -- VMware Confidential
import time
import sha.config

from sha.contrib.action.abc_base import Action
from vmware.nsx.sha import sha_pb2

from sha.contrib.action.utils.check import should_report

from sha.constants import REPORT_INTERVAL, SMALLEST_REPORT_INTERVAL_IF_CHANGE
from sha.core.channel.provider.mpa_provider import ReportMsg

class Msreport(Action):
    _logger = sha.config.get_logger(__name__)
    pre_report_msg = None
    pre_report_time = None
    # indicate whether pre report is caused by data change
    pre_reported_by_change = False

    @classmethod
    def populate_pb_msg(cls, **kwargs):
        report_msg = sha_pb2.ShaReportMsg()
        report_msg.oid.left = sha.config.HOST_ID_LOW
        report_msg.oid.right = sha.config.HOST_ID_HIGH
        ms_status = kwargs['ms_status']
        status_msg = report_msg.status.add()
        status_msg.type = sha_pb2.ShaStatusMsg.ShaStatusType.Value('MIRROR_STACK')
        status_msg.ms_stack_status.dedicated_stack_status = ms_status["dedicated_stack_status"]
        status_msg.ms_stack_status.vmknic_status = ms_status["vmknic_status"]
        status_msg.ms_stack_status.session_id.extend(ms_status["session_ids"])
        status_msg.ms_stack_status.description = (ms_status["description"])
        return report_msg.SerializeToString()

    @classmethod
    def do(cls, hub, *args):
        def kernel(**kwargs):
            cls._logger.debug('Msreport - signaling, status:{}, profile:{}'
                              .format(kwargs['ms_status'], kwargs['profile']))
            pb_msg = Msreport.populate_pb_msg(**kwargs)
            profile = kwargs['profile']
            do_report, report_by_change = \
                should_report(cls.pre_report_msg, cls.pre_report_time, cls.pre_reported_by_change, pb_msg,
                              profile[REPORT_INTERVAL], profile[SMALLEST_REPORT_INTERVAL_IF_CHANGE])
            cls._logger.debug('Msreport - signaling, do_report:{}, report_by_change:{}'
                              .format(do_report, report_by_change))

            if do_report:
                cls._logger.debug('Msreport - reporting, status:{}, profile:{}'
                                  .format(kwargs['ms_status'], kwargs['profile']))
                hub.send(ReportMsg(b'', pb_msg, b'com.vmware.nsx.sha.ShaReportMsg'))
                cls.pre_report_time = time.monotonic()
                cls.pre_report_msg = pb_msg
                cls.pre_reported_by_change = report_by_change

        return kernel
