# Copyright (C) 2020 VMware, Inc. All rights reserved.
# -- VMware Confidential
from sha.core.channel.provider.mpa_provider import ReportMsg
from vmware.nsx.sha import sha_pb2

import sha.config
import sha.constants
from sha.contrib.action.abc_base import Action
from sha.config_monitor import ConfigMonitor


class Psreport(Action):
    _logger = sha.config.get_logger(__name__)

    @classmethod
    def populate_pb_msg(cls, plugin_status_list):
        report_msg = sha_pb2.ShaReportMsg()
        report_msg.oid.left, report_msg.oid.right = ConfigMonitor.host_id_low_high()
        status_msg = report_msg.status.add()
        status_msg.type = sha_pb2.ShaStatusMsg.ShaStatusType.Value(sha.constants.PLUGIN)
        for plugin_status in plugin_status_list:
            plugin_status_msg = status_msg.plugin_status.status.add()
            plugin_status_msg.name = plugin_status[sha.constants.NAME]
            plugin_status_msg.status = sha_pb2.PluginStatusMsg.PluginStatusType.Value(plugin_status[sha.constants.STATUS])
            plugin_status_msg.plugin_id = plugin_status[sha.constants.PLUGIN_ID]
            if plugin_status.get(sha.constants.DETAIL, None):
                plugin_status_msg.detail = plugin_status[sha.constants.DETAIL]
            if plugin_status.get(sha.constants.PROFILE, None):
                plugin_status_msg.profile = plugin_status[sha.constants.PROFILE]

        return report_msg.SerializeToString()

    @classmethod
    def report(cls, hub, plugin_status_list):
        pb_msg = Psreport.populate_pb_msg(plugin_status_list)
        cls._logger.debug('signaling: list: {}'.format(plugin_status_list))
        hub.send(ReportMsg(b'', pb_msg, b'com.vmware.nsx.sha.ShaReportMsg'))




