# Copyright (C) 2019-2020 VMware, Inc. All rights reserved.
# -- VMware Confidential
import sha.config

from sha.contrib.metric.daemon_health import DaemonHealth
from sha.contrib.metric.hyperbus_connection_list import HyperbusConnectionList
from sha.contrib.metric.host_metrics import HostMetrics
from sha.contrib.metric.vmk_list import VMKList
from sha.contrib.metric.vdr_stats import VdrStats
from sha.contrib.metric.mirror_stack_status import MirrorStackStatus
from sha.contrib.metric.audit_log_health_for_local_error_status import AuditLogHealthForLocalErrorStatus
from sha.contrib.metric.audit_log_health_for_remote_error_status import AuditLogHealthForRemoteErrorStatus
from sha.contrib.metric.manager_fqdn_lookup_failure_status import ManagerFqdnLookupFailureStatus
from sha.contrib.metric.manager_fqdn_reverse_lookup_failure_status import ManagerFqdnReverseLookupFailureStatus

__all__ = [
    'HyperbusConnectionList',
    'DaemonHealth',
    'HostMetrics',
    'VMKList',
    'VdrStats',
    'MirrorStackStatus',
    'AuditLogHealthForLocalErrorStatus',
    'AuditLogHealthForRemoteErrorStatus',
    'ManagerFqdnLookupFailureStatus',
    'ManagerFqdnReverseLookupFailureStatus',
]

if sha.config.NODE_TYPE == sha.config.DIST_EDGE:
    from sha.contrib.metric.edge_fw_stats import EdgeFWStats
    from sha.contrib.metric.edge_fw_conn import EdgeFWConn
    from sha.contrib.metric.edge_ipsec_vpn_stats import EdgeIpsecVpnStats
    from sha.contrib.metric.edge_status import EdgeStatus
    from sha.contrib.metric.edge_sr_state import EdgeSrState
    from sha.contrib.metric.lb_status import LbStatus

    edge_metrics = [
        'EdgeFWStats',
        'EdgeFWConn',
        'EdgeIpsecVpnStats',
        'EdgeStatus',
        'EdgeSrState',
        'LbStatus',
    ]
    __all__.extend(edge_metrics)

elif sha.config.NODE_TYPE == sha.config.DIST_ESX:
    from sha.contrib.metric.lb_status import LbStatus

    esx_metrics = [
        'LbStatus',
    ]
    __all__.extend(esx_metrics)

elif sha.config.NODE_TYPE == sha.config.DIST_UA:
    from sha.contrib.metric.top_process_list import TopProcessList
    from sha.contrib.metric.ua_node_latency_list import UaNodeLatencyList

    ua_metrics = [
        'TopProcessList',
        'UaNodeLatencyList',
    ]

    __all__.extend(ua_metrics)

# For all 3 edge types
if sha.config.node_type_is(sha.config.DIST_EDGE, sha.config.DIST_AUTONOMOUS_EDGE,
                           sha.config.DIST_PUBLIC_CLOUD_GATEWAY):
    from sha.contrib.metric.edge_mgmt_interface_status import EdgeMgmtInterface
    from sha.contrib.metric.rcu_event_status import EdgeRcuBlock

    __all__.append('EdgeMgmtInterface')
    __all__.append('EdgeRcuBlock')
