# Copyright (C) 2020 VMware, Inc. All rights reserved.
# -- VMware Confidential
from sha import config
from sha.core.channel.hub import Hub
from sha.core.channel.provider import MpaProvider, AlarmProvider, WfProvider


class HubHolder:
    _logger = config.get_logger(__name__)

    _mpa_hub = Hub(MpaProvider(), 'MpaHub')
    _alarm_hub = Hub(AlarmProvider(), 'AlarmHub')
    _wf_hub = Hub(WfProvider(), 'WfHub')

    @classmethod
    def start_hubs(cls):
        cls._logger.info("starting MpaHub")
        cls._mpa_hub.start()
        cls._logger.info("starting AlarmHub")
        cls._alarm_hub.start()
        cls._logger.info("starting wavefront Hub")
        cls._wf_hub.start()

    @classmethod
    def stop_hubs(cls):
        cls._logger.info("stopping MpaHub")
        cls._mpa_hub.stop()
        cls._logger.info("stopping AlarmHub")
        cls._alarm_hub.stop()
        cls._logger.info("stopping wavefront Hub")
        cls._wf_hub.stop()

    @classmethod
    def wait_hubs_stop(cls):
        cls._mpa_hub.join()
        cls._alarm_hub.join()
        cls._wf_hub.join()

    @classmethod
    def mpa_hub(cls):
        return cls._mpa_hub

    @classmethod
    def alarm_hub(cls):
        return cls._alarm_hub

    @classmethod
    def wf_hub(cls):
        return cls._wf_hub
