import traceback
import sha.config
from sha.core.notifier._loop_notifier_v1 import LoopNotifierV1
from sha.core.plugin.plugin_status_collection import PluginStatusCollection
from sha.core.plugin._plugin import Plugin


class CustomPluginNotifierManager:
    """
    Manage LoopNotifier for custom plugin
    """
    _logger = sha.config.get_logger(__name__)
    _notifiers = {}

    @classmethod
    def stop_all_notifiers(cls):
        for notifier in cls._notifiers.values():
            notifier.stop()

    @classmethod
    def remove_notifier(cls, plugin_id):
        notifier = None
        try:
            notifier = cls._notifiers.get(plugin_id, None)
            if not notifier:
                PluginStatusCollection.remove_plugin_status(plugin_id)
                cls._logger.warn('Not found loop_notifier for plugin id:{}, no need to perform removal.'
                                 .format(plugin_id))
                return
            notifier.stop()
            cls._notifiers.pop(plugin_id)
            cls._logger.info('Removed loop_notifier for plugin:{}, all loop_notifiers:{}'
                             .format(notifier.plugin, cls._notifiers))
        except Exception as e:
            trace = traceback.format_exc()
            cls._logger.warn('Failed in removing loop_notifier for plugin: {}, exception:{}, trace:{}'
                             .format(notifier.plugin, e, trace))

    @classmethod
    def add_notifier(cls, custom_plugin):
        try:
            plugin = Plugin.custom_plugin(custom_plugin.script,
                                          custom_plugin.manifest,
                                          custom_plugin.id,
                                          custom_plugin.name)

            # make custom plugins runs on whiteboard framework
            loop_notifier = LoopNotifierV1(plugin=plugin)
            cls._notifiers[loop_notifier.plugin.id] = loop_notifier
            loop_notifier.start()
            cls._logger.info('Added loop_notifier for plugin:{}, all loop_notifiers:{}'.format(plugin, cls._notifiers))
        except Exception as e:
            trace = traceback.format_exc()
            cls._logger.error('Failed in adding loop_notifier for plugin: {}, exception:{}, trace:{}'
                              .format(custom_plugin, e, trace))
            PluginStatusCollection.update_plugin_status(custom_plugin.id, sha.constants.ERROR,
                                                        'Failed in adding loop_notifier. error:' + str(e))

    @classmethod
    def get_notifiers(cls):
        return cls._notifiers
