# Copyright (C) 2019-2020 VMware, Inc. All rights reserved.
# -- VMware Confidential


def handle_notification(notification, profile):
    if not notification:
        logger.error('Notification is empty.')
        return

    FEATURE_NAME = 'transport_node_health'
    event_types = {
        'UPLINK_DOWN_ALARM': 'nvds_uplink_down',
        'LAG_MEMBER_DOWN_ALARM': 'lag_member_down',
    }
    status_changes = notification[0]
    lag_member_down_evt_type_id = feature_event_type_mappings.TRANSPORT_NODE_HEALTH_LAG_MEMBER_DOWN_EVENT_TYPE_ID
    nvds_uplink_down_evt_type_id = feature_event_type_mappings.TRANSPORT_NODE_HEALTH_NVDS_UPLINK_DOWN_EVENT_TYPE_ID

    for alarm, status in status_changes.items():
        event_type = event_types[alarm]
        if event_type == "nvds_uplink_down":
            return Alarm(status={nvds_uplink_down_evt_type_id: {data_store['host_id']: (status, None)}}, feature=FEATURE_NAME)
        else:
            return Alarm(status={lag_member_down_evt_type_id: {data_store['host_id']: (status, None)}}, feature=FEATURE_NAME)

logger.info('data_store:{}'.format(data_store))
profile = data_store['profile']
if data_store['metrics']['nsx.uplink.uplink-status']:
    notification = data_store['metrics']['nsx.uplink.uplink-status']['value']
    handle_notification(notification, profile)
else:
    # Reactive plugin is only trigged when new metric data coming. Metric shouldn't be None.
    # But for UplinkStatusMonitor, notifier will read metric proactively and notify plugin with metric
    # when profile is changed to enabled or precondition is changed to reached.
    logger.info('No nsx.uplink.uplink-status metric: {}'.format(data_store['metrics']))
