# Copyright (C) 2020 VMware, Inc. All rights reserved.
# -- VMware Confidential
import os
import platform
import sys
import yaml
import nsx_logging


SHA_ROOT_DIR = os.path.dirname(os.path.abspath(__file__))
LOG_LEVEL = nsx_logging.INFO
SYSTEM = platform.system()

PLATFORM_ESX = "VMkernel"
PLATFORM_LINUX = "Linux"
PLATFORM_WINDOWS = "Windows"

# Config nsx logging
def init_log():
    log_config_path = os.path.join(SHA_ROOT_DIR, 'logconfig.yml')
    if SYSTEM != PLATFORM_WINDOWS:
        nsx_logging.init(log_config_path)
        return

    with open(log_config_path) as f:
        config = yaml.load(f.read(), Loader=yaml.Loader)
    config['handlers']['file']['filename'] = os.environ.get("PROGRAMDATA") + "\\VMware\\NSX\\Logs\\nsx-sha.log"
    nsx_logging.config.dictConfig(config)


init_log()

_logger = nsx_logging.getLogger(__name__)
_logger.info('nsx_logging is coming from %s' % nsx_logging.__file__)

class sha_logger():
    def __init__(self, name, s2comp):
        self._s2comp = s2comp
        self._logger = nsx_logging.getLogger(name)

    def error(self, message, *args, **kwargs):
        self._logger.error(message, s2comp=self._s2comp, *args, **kwargs)

    def warning(self, message, *args, **kwargs):
        self._logger.warning(message, s2comp=self._s2comp, *args, **kwargs)

    def info(self, message, *args, **kwargs):
        self._logger.info(message, s2comp=self._s2comp, *args, **kwargs)

    def debug(self, message, *args, **kwargs):
        self._logger.debug(message, s2comp=self._s2comp, *args, **kwargs)

def get_sub_logger(name, s2comp=None):
    if not s2comp:
        return nsx_logging.getLogger(name)
    else:
        return sha_logger(name, s2comp)
